@@ -49,8 +49,8 @@
 #          - 1.03 : Code cleaning and commenting, fixed doc.
 #  9    99 - 1.04 : Imperativo of second plural follows a simple rule
 #            which I had overlooked. Fixed. Some places where
-#            "Dicinario Online da Lingua Portuguesa" (DLPO) and "Guia
-#            Prtica dos Verbos Portugueses" (GPVP) differ have been
+#            "Diciónario Online da Lingua Portuguesa" (DLPO) and "Guia
+#            Prática dos Verbos Portugueses" (GPVP) differ have been
 #            docummented in the verb database at end of this file.
 ##
 # 12  2000 - Incorporate Unconjugate-related stuff
@@ -58,7 +58,7 @@
 #
 # See recent changes in file ChangeLog
 
-$VERSION = '1.18' ;
+$VERSION = '1.19' ;
 
 # Just to make sure which file is loaded
 # BEGIN{ print "SEE THIS ???\n",`pwd` }
@@ -84,6 +84,8 @@ package Lingua::PT::Conjugate;
 # 
 
 package Lingua::PT::Accent_iso_8859_1;
+use feature 'unicode_strings';
+use utf8;
 use Exporter ;
 @ISA = qw(Exporter);
 # Yes, this package is a namespace polluter. 
@@ -153,10 +155,12 @@ $find_ascii_accent = join("|",keys(%ascii2iso_keys));
 
 
 # Crude code
-sub un_accent { 
-		return unless(defined @_);
-		my @a=@_;
-		iso2asc(map {s/[\'\`\^\~]([aAeEiIoOuU])/$1/g; $_} @a) 
+sub un_accent 
+{ 
+    ## return unless(defined @_);
+    return unless @_;
+    my @a=@_;
+    iso2asc(map {s/[\'\`\^\~]([aAeEiIoOuU])/$1/g; $_} @a) 
 }
 
 sub iso2asc {
@@ -194,7 +198,7 @@ import Lingua::PT::Accent_iso_8859_1 qw(iso2asc asc2iso un_accent);
 use Exporter ;
 @ISA = qw(Exporter);
 # Yes, this package is a namespace polluter. 
-@EXPORT = qw(conjug); 
+@EXPORT = qw(conjug env_is_utf8); 
 
 @EXPORT_OK = qw( cedilla codify end_gu end_oiar end_uir
 				 end_zer hard_c hard_g list_verbs locate same_model
@@ -251,7 +255,7 @@ use Exporter ;
 			  "cfut"=>"conjuntivo futuro",
 			  "cond" =>"condicional",
 			  "ivo"  =>"imperativo",
-			  "pp"=>"particpio passado", #'
+			  "pp"=>"particípio passado", #'
 			  "grd"  =>"gerundivo" ,
 			 );
 
@@ -273,40 +277,50 @@ use Exporter ;
 		  "cpres",[],"cimp",[],"cfut",[],"cond",[],"ivo",[],
 		  "pp",[],"grd",[]);
 
+sub strHash
+{
+    my $a = $_[0];
+    "{ " . join (", ", map {"'".$_."' => '".$a{$_}."'"} sort keys %$a) . " }";
+}
+
 # ####################### VOCALS, CONSONANTS ##################### 
 # Vocals and Consonants   
-$vocs = "aeiou";
+$vocs = "aeiouáàäâãéèëêíìïîóòöôõúùüû";
 $plainvoc = "aeiou";
-$accvoc = "";
+$accvoc = "áàäâãéèëêíìïîóòöôõúùüû";
 # Char => accent
 $only_acc = 
-  {split("","\'\`\"^~\'\`\"^\'\`\"^\'\`\"^~\'\`\"^")};
+  {split("",$foo="á\'à\`ä\"â\^ã\~é\'è\`ë\"ê^í\'ì\`ï\"î\^ó\'ò\`ö\"ô\^õ\~ú\'ù\`ü\"û\^")};
+
+#print "only_acc = '", join("', '",%$only_acc), "'\n"; 
+#print "only_acc = ",strHash($only_acc),"\n";
+#print "foo='$foo' = >>",join("<>",split("",$foo)),"<<\n";
 # Char => unaccentuated
 $no_acc = 
-  {split("","aaaaaeeeeiiiiooooouuuu")};
+  {split("","áaàaäaâaãaéeèeëeêeíiìiïiîióoòoöoôoõoúuùuüuûu")};
 $vpat = "[$vocs]";
 $cons = 'qwrtypsdfghjklzxcvbnm';
-$cpat = "(?:[$cons]+||gu)";
-$wpat = "[$vocs$cons]";
-$letter = "$vocs$cons";
+$cpat = "(?:[$cons]+|ç|gu)";
+$wpat = "[ç$vocs$cons]";
+$letter = "ç$vocs$cons";
 
 # pres perf imp fut mdp  cpres cimp cfut cond ivo pp grd 
 # ##############  REGULAR EXPRESSIONS THAT MATCH VERB ENDINGS ############
 %endg = %{verbify( q"
-      o   [aein]s  [aeim] [eaio]mos [ae]?[i]s [ae]m,
-      e?[is]   [aei]ste  [eio][us] [aei]mos [aei]stes [aei]ram,
-      (?:av|i)?a   (?:av|i)?as   (?:av|i)?a (?:av|v||i)?[a]mos
-      (?:av|v||i)?[a]?eis (?:av|i)?am, 
-      [aeio]rei [aeio]r[a]s [aeio]r[a] [aeio]r[ae]mos [aeio]reis
-      [aeio]ro,
-      [aei]ra [aei]ras [aei]ra [aei]ramos [aeiaei]reis [aei]ram,
+      o   [aeiín]s  [aeim] [eaioí]mos [ae]?[ií]s [ae]m,
+      e?[íis]   [aeií]ste  [eio][us] [aeií]mos [aeií]stes [aeií]ram,
+      (?:av|i)?a   (?:av|i)?as   (?:av|i)?a (?:av|áv|í|i)?[aá]mos
+      (?:av|áv|í|i)?[aá]?eis (?:av|i)?am, 
+      [aeio]rei [aeio]r[aá]s [aeio]r[aáâ] [aeio]r[ae]mos [aeio]reis
+      [aeio]rão,
+      [aeií]ra [aeií]ras [aeií]ra [aeiâáêéîí]ramos [aeiaeiâáêéîí]reis [aeií]ram,
       [aeo] [ae]s [ae] [ae]mos [aei]s [ae]m,
-      [ae]sse [ae]sses [ae]sse [ae]ssemos [aei]sseis [ae]ssem,
-      [aei]r [aei]res [aei]r [aei]rmos [aei]rdes [aei]rem, 
-      [aeio]ria [aeio]rias [aeio]ria [aeio]r[i]amos
-      [aeio]r[aeio]eis [aeio]riam, 
-      [aeim] [ae] [ae]mos (?:i|de|) [ae]m ,
-      (?:[ai]do|to) , [aeio]ndo " 
+      [aeí]sse [aeí]sses [aeí]sse [aeâáêéí]ssemos [aeiâáêéîí]sseis [aeí]ssem,
+      [aei]r [aeií]res [aei]r [aei]rmos [aei]rdes [aeií]rem, 
+      [aeio]ria [aeio]rias [aeio]ria [aeio]r[iíî]amos
+      [aeio]r[aeioâáêéîíóòô]eis [aeio]riam, 
+      [aeim] [ae] [ae]mos (?:i|de|í) [ae]m ,
+      (?:[aií]do|to) , [aeio]ndo " 
 				 )};
 
 # print join(",",%endg);
@@ -318,13 +332,13 @@ $letter = "$vocs$cons";
 		"er" => verbify( q{
 		  o   es     e emos eis em,
 		  i   este  eu emos estes eram,
-		  ia   ias   ia amos eis iam,
-		  erei ers er eremos ereis ero,
-		  era eras era ramos reis eram,
+		  ia   ias   ia íamos íeis iam,
+		  erei erás erá eremos ereis erão,
+		  era eras era êramos êreis eram,
 		  a as a amos ais am,
-		  esse esses esse ssemos sseis essem,
+		  esse esses esse êssemos êsseis essem,
 		  er eres er ermos erdes erem, 
-		  eria erias eria eramos ereis eriam,
+		  eria erias eria eríamos eríeis eriam,
 		  e a amos ei am ,
 		  ido , endo ,
 		}) ,
@@ -333,13 +347,13 @@ $letter = "$vocs$cons";
 		"ar" => verbify( q{
 		  o   as     a  amos  ais     am , 
 		  ei   aste  ou  amos  astes  aram ,
-		  ava   avas  ava  vamos veis avam ,
-		  arei ars ar aremos  areis  aro,
-		  ara aras ara ramos reis aram ,
+		  ava   avas  ava  ávamos áveis avam ,
+		  arei arás ará aremos  areis  arão,
+		  ara aras ara áramos áreis aram ,
 		  e es e emos eis em ,
-		  asse  asses asse ssemos sseis assem,
+		  asse  asses asse ássemos ásseis assem,
 		  ar ares ar armos ardes arem,
-		  aria arias aria aramos areis ariam,
+		  aria arias aria aríamos aríeis ariam,
 		  a e emos ai em ,
 		  ado , ando ,
 		} ),
@@ -348,28 +362,28 @@ $letter = "$vocs$cons";
 		"ir" => verbify( q{
 		  o   es     e  imos   is    em , 
 		  i   iste  iu  imos   istes  iram ,
-		  ia   ias   ia  amos eis iam ,
-		  irei irs ir iremos ireis  iro,
-		  ira iras ira ramos reis iram,
+		  ia   ias   ia  íamos íeis iam ,
+		  irei irás irá iremos ireis  irão,
+		  ira iras ira íramos íreis iram,
 		  a as a amos ais am,
-		  isse isses isse ssemos sseis issem,
+		  isse isses isse íssemos ísseis issem,
 		  ir ires ir irmos irdes irem,
-		  iria irias iria iramos ireis iriam,
+		  iria irias iria iríamos iríeis iriam,
 		  e a amos i am ,
 		  ido , indo ,
 		} ),
 		
 		"or" => verbify(q{ 
-		  onho es e omos ondes em ,
-		  us useste s usemos usestes useram , 
-		  unha unhas unha nhamos nheis unham,
-		  orei ors or oremos oreis oro,
-		  usera useras usera usramos usreis useram,
+		  onho ões õe omos ondes õem ,
+		  us useste ôs usemos usestes useram , 
+		  unha unhas unha únhamos únheis unham,
+		  orei orás orá oremos oreis orão,
+		  usera useras usera uséramos uséreis useram,
 		  onha onhas onha onhamos onhais onham,
-		  usesse usesses usesse usssemos usseis usessem,
+		  usesse usesses usesse uséssemos uésseis usessem,
 		  user useres user usermos userdes userem,
-		  oria orias oria oramos oreis oriam,
-		  e onha onhamos onde onham
+		  oria orias oria oríamos oríeis oriam,
+		  õe onha onhamos onde onham
 		  pp osto grd ondo
 		}),
 	   );
@@ -378,72 +392,72 @@ $letter = "$vocs$cons";
 # pres perf imp fut mdp  cpres cimp cfut cond ivo pp grd 
 %verb = (
 		 "ter"=>verbify( q{ 
-		   tenho tens tem temos tendes tm ,
+		   tenho tens tem temos tendes têm ,
 		   tive tiveste teve tivemos tivestes tiveram,
-		   tinha tinhas tinha tnhamos tnheis tinham,
-		   terei ters ter teremos tereis tero,
-		   tivera tiveras tivera tivramos tivreis tiveram,
+		   tinha tinhas tinha tínhamos tínheis tinham,
+		   terei terás terá teremos tereis terão,
+		   tivera tiveras tivera tivéramos tivéreis tiveram,
 		   tenha tenhas tenha tenhamos tenhais tenham,
-		   tivesse tivesses tivesse tivssemos tivsseis tivessem,
+		   tivesse tivesses tivesse tivéssemos tivésseis tivessem,
 		   tiver tiveres tiver tivermos tiverdes tiverem,
-		   cond teria terias teria teramos tereis teriam,
+		   cond teria terias teria teríamos teríeis teriam,
 		   ivo tem tenha tenhamos tende tenham ,
 		   tido tendo 
 		 } ),
 		 
 		 "ser"=>verbify( q{
-		   sou s  somos sois so, 
+		   sou és é somos sois são, 
 		   fui foste foi fomos fostes foram,
-		   era eras era ramos reis eram,
-		   serei sers ser seremos sereis sero ,
-		   fora foras fora framos freis foram ,
+		   era eras era éramos éreis eram,
+		   serei serás será seremos sereis serão ,
+		   fora foras fora fôramos fôreis foram ,
 		   seja sejas seja sejamos sejais sejam,
-		   fosse fosses fosse fssemos fsseis fossem,
+		   fosse fosses fosse fôssemos fôsseis fossem,
 		   for fores for formos fordes forem,
-		   seria serias seria seramos sereis seriam,
-		   s seja sejamos sede sejam,
+		   seria serias seria seríamos seríeis seriam,
+		   sê seja sejamos sede sejam,
 		   sido sendo
 		 } ),
 		 
 		 "estar"=>verbify( q{
-		   estou ests est estamos estais esto,
+		   estou estás está estamos estais estão,
 		   estive estiveste esteve estivemos estivestes estiveram,
-		   estava estavas estava estvamos estveis estavam,
-		   estarei estars estar estaremos estareis estaro,
-		   estivera estiveras estivera estivramos estivreis estiverm,
+		   estava estavas estava estávamos estáveis estavam,
+		   estarei estarás estará estaremos estareis estarão,
+		   estivera estiveras estivera estivéramos estivéreis estiverãm,
 		   esteja estejas esteja estejamos estejais estejam,
-		   estivesse estivesses estivesse estivssemos estivsseis estivessem,
+		   estivesse estivesses estivesse estivéssemos estivésseis estivessem,
 		   estiver estiveres estiver estivermos estiverdes estiverem,
-		   estaria estarias estaramos estareis estariam,
-		   est estja estejamos estai estejam,
+		   estaria estarias estaríamos estaríeis estariam,
+		   está estéja estejamos estai estejam,
 		   estado estando
 		 } ),
 		 
 		 "haver"=>verbify( q{
-		   hei hs h havemos haveis ho,
+		   hei hás há havemos haveis hão,
 		   houve houveste houve houvemos houvestes houveram,
-		   havia havias havia havamos haveis haviam,
-		   haverei havers haver haveremos havereis havero,
-		   houvera houveras houvera houvramos houvreis houveram,
+		   havia havias havia havíamos havíeis haviam,
+		   haverei haverás haverá haveremos havereis haverão,
+		   houvera houveras houvera houvéramos houvéreis houveram,
 		   haja hajas haja hajamos hajais hajam,
-		   houvesse houvesses houvesse houvssemos houvsseis houvessem,
+		   houvesse houvesses houvesse houvéssemos houvésseis houvessem,
 		   houver houveres houver houvermos houverdes houverem,
-		   haveria haverias haveria haveramos havereis haveriam,
+		   haveria haverias haveria haveríamos haveríeis haveriam,
 		   hajas haja hajamos havei hajam, havido  havendo
 		 } ),
 		 
 		 # pres perf imp fut mdp  cpres cimp cfut cond ivo pp grd 
-		 "pr"=>verbify( q{  pr
-		     ponho pes pe pomos pondes pem ,
-  		     pus puseste ps pusemos pusestes puseram , 
- 		     punha punhas punha pnhamos pnheis punham,
-		     porei pors por poremos poreis poro,
-   		     pusera puseras pusera pusramos pusreis puseram,
+		 "pôr"=>verbify( q{  pôr
+		     ponho pões põe pomos pondes põem ,
+  		     pus puseste pôs pusemos pusestes puseram , 
+ 		     punha punhas punha púnhamos púnheis punham,
+		     porei porás porá poremos poreis porão,
+   		     pusera puseras pusera puséramos puséreis puseram,
 		     ponha ponhas ponha ponhamos ponhais ponham,
-		     cimp pusesse pusesses pusesse pusssemos pussseis pusessem,
+		     cimp pusesse pusesses pusesse puséssemos pusésseis pusessem,
 		     puser puseres puser pusermos puserdes puserem,
-          	     poria porias poria poramos poreis poriam,
- 		     pe ponha ponhamos ponde ponham
+          	     poria porias poria poríamos poríeis poriam,
+ 		     põe ponha ponhamos ponde ponham
         	     pp posto grd pondo
 		     }),
 		 
@@ -491,7 +505,7 @@ sub verbify {
   # print "verbify >$a<\n";
   
   # There may not be a root, see e.g. initial calls to verbify.
-  if( $_[0] =~ /([aeio]r)$/ ){ 
+  if( $_[0] =~ /([aeioô]r)$/ ){ 
 	  
 	
 	  # Extract Root and Ending
@@ -575,7 +589,7 @@ sub verbify {
 		  while( $p < 6 ){
 			  $res{$t}->[$p] = $x . $reg{$edg2}->{$t}->[$p] unless 
 				  $p==3 && $reg{$edg2}->{$t}->[$p] =~ /^i/ && 
-					  $x =~ /i([$cons]{1,2}||gu)$/o   ;
+					  $x =~ /i([$cons]{1,2}|ç|gu)$/o   ;
 			  # print "$t , $p , $res{$t}->[$p] <<\n";
 			  $p++;
 		  }
@@ -612,7 +626,7 @@ sub verbify {
 	$res{$t}->[3] = conjug({"$root$edg"=>\%res},"s","$root$edg",$t,4);
 	# Before iso-accentuating all 
 	# $res{$t}->[3] =~ tr/\'\^/\^\'/ ;
-	$res{$t}->[3] =~ tr/// ;
+	$res{$t}->[3] =~ tr/áéíâêî/âêîáéí/ ;
   }
   \%res;
   
@@ -851,7 +865,7 @@ sub soft_g {
 sub soft_c {
   my ( $w , $root, $edg , $p , $t ) = @_ ;
   
-  $w=~ s/c([^c]+)$/$1/ if( $w =~ /c[aou][^c]*$/);
+  $w=~ s/c([^c]+)$/ç$1/ if( $w =~ /c[aou][^c]*$/);
   $w ;
 }
 
@@ -872,7 +886,7 @@ sub hard_c {
 sub cedilla {
   my ( $w , $root, $edg , $p , $t ) = @_ ;
   
-  $w =~ s/[e]([^]*)$/ce$1/;
+  $w =~ s/ç[e]([^ç]*)$/ce$1/;
   $w;
 }
 
@@ -886,7 +900,7 @@ sub end_gu {
 #sub end_oiar {
 # my ( $w , $root, $edg , $p , $t ) = @_ ;
 #
-# $w =~ s/o// ;
+# $w =~ s/oó/ó/ ;
 # $w;
 #}
 
@@ -906,7 +920,7 @@ sub end_uir {
 	$t eq "pres" && ($p==2||$p==3) ||$t eq "ivo" && $p == 2 ;
   
   # Here ??Needed??
-  $w =~ s/$root i/ $root. ""/ex if
+  $w =~ s/$root i/ $root. "í"/ex if
 	$t eq "imp" || $t eq "mdp" || $t eq "perf" && $p!=3 || 
 	  $t eq "pres" && $p==4 ;
   
@@ -918,7 +932,7 @@ sub is_defectivo
   my ( $verb, $v, $t, $p ) = @_ ;
   return 0 unless exists( $verb->{defectivos}->{$v} ) ;
   # Check that verb looks like a verb 
-  unless( $v =~ /^(.*)([aeio]r)$/ ){ 
+  unless( $v =~ /^(.*)([aeioô]r)$/ ){ 
     warn "$v does not look like a verb." ;
     next;
   }
@@ -932,7 +946,7 @@ sub is_defectivo
 		   /["^$vocs"]*["$vocs"]["^$vocs"]*["$vocs"]/o ||
 		   $reg{$edg}->{$t}->[$p-1] =~
 		   /["^$vocs"]*(["$vocs"])/o && 
-		   ($1 eq "i" ||  $1 eq "" || 
+		   ($1 eq "i" ||  $1 eq "í" || 
 		    "$verb->{defectivos}->{$v}" eq "2" && $1 eq "e") 
 		 )
 		|| "$verb->{defectivos}->{$v}" eq "4" && $p!=3 && $p!=6
@@ -963,7 +977,7 @@ sub conjug {
 #  while( ($v=shift) && ($v=~ /^\-? [hvqlrcsxio]+ $/x ) ){
   while( @_ && (($v = shift) =~ /^\-? [hvqlrcsxio]+ $/x ) ){
 	# print "option $v\n";
-	if( $v=~/[iaeo]r$/ ){	# That looks like a verb
+	if( $v=~/[iaeoô]r$/ ){	# That looks like a verb
 	  # unshift @_,$v;
 	  # print "NOT OPT\n";
 	  last ;
@@ -1051,7 +1065,7 @@ sub conjug {
 	# print " D2 " if $verb->{defectivos}->{$v};
 	
 	# Check that verb looks like a verb 
-	unless( $v =~ /^(.*)([aeio]r)$/ ){ 
+	unless( $v =~ /^(.*)([aeioô]r)$/ ){ 
 	  warn "$v does not look like a verb." ;
 	  next;
 	}
@@ -1063,7 +1077,7 @@ sub conjug {
     if   ( $v =~ /g[ei]r$/ )    {  $modif = \&soft_g }
     elsif( $v =~ /c[ei]r$/ )    {  $modif = \&soft_c }
     elsif( $v =~ /g[ao]r$/ )    {  $modif = \&hard_g }
-    elsif( $v =~ /ar$/ )       {  $modif = \&cedilla }
+    elsif( $v =~ /çar$/ )       {  $modif = \&cedilla }
     elsif( $v =~ /c[ao]r$/ )    {  $modif = \&hard_c }
     elsif( $v =~/gu[ei]r$/ )    {  $modif = \&end_gu }
     elsif( $v =~ /[^g]uir$/)    {  $modif = \&end_uir }
@@ -1083,7 +1097,7 @@ sub conjug {
     else                        { $modif = 0 }
 	
 	# if($v =~/or$/){       # verbs in "or"
-	# $verb->{$v}->{model} = "pr" unless defined($verb->{$v});
+	# $verb->{$v}->{model} = "pôr" unless defined($verb->{$v});
 	# }
 	
     if($verbose)
@@ -1460,6 +1474,19 @@ sub tabrow {
   $res =~ s/\n[\n\s]+/\n/mg;
   $res;
 }
+
+sub env_is_utf8 ()
+{
+	foreach my $v (qw(LC_ALL LC_TYPE LANG))
+	{
+		if (exists ($ENV{$v}) && defined ($ENV{$v}))
+		{
+			return $ENV{$v} =~ /utf-?8/i;
+		}
+	}
+	return undef;
+} 
+
 ######################################################################
 
 
@@ -1486,28 +1513,28 @@ BEGIN {
 
     $vlist = <<EOD ; 
 
-obter: obtenho obtns obtm ivo obtm model ter 
-abster: abstenho abstns abstm ivo abstm model ter 
-ater: atenho atns atm ivo atm model ter 
-conter: contenho contns contm ivo contm model ter 
-deter: detenho detns detm ivo detm model ter 
-entreter: entretenho entretns entretm ivo entretm model ter 
-reter: retenho retns retm ivo retm model ter 
-suster: sustenho sustns sustm ivo sustm model ter 
+obter: obtenho obténs obtém ivo obtém model ter 
+abster: abstenho absténs abstém ivo abstém model ter 
+ater: atenho aténs atém ivo atém model ter 
+conter: contenho conténs contém ivo contém model ter 
+deter: detenho deténs detém ivo detém model ter 
+entreter: entretenho entreténs entretém ivo entretém model ter 
+reter: retenho reténs retém ivo retém model ter 
+suster: sustenho susténs sustém ivo sustém model ter 
 
 # obter = abster ater conter deter entreter reter suster # phoey
 boiar:
-  bio etc 
-  cpres bie bies bie boiemos biem
-  ivo bia bie boiemos biem
+  bóio etc 
+  cpres bóie bóies bóie boiemos bóiem
+  ivo bóia bóie boiemos bóiem
 # This one has ivo,p=5 perdoeis in GPVP, perdoai in DLPO
 perdoar:
   perdoo perdoas perdoa perdoamos perdoam 
 moer:
-  moo mos mi moemos moem,
-  mo, 
-  moa moas  moa moamos moam, cfut moer etc cimp moesse etc
-  ivo mi pp modo
+  moo moís mói moemos moem,
+  moí, 
+  moía moías  moía moíamos moíam, cfut moer etc cimp moesse etc
+  ivo mói pp moído
 passear:
   passeio passeias passeia passeamos passeiam,
   cpres passeie passeies passeie passeemos passeeis  passeiem
@@ -1522,7 +1549,7 @@ dizer:
   disse disseste disse dissemos disseram,,
   direi etc
   cpres diga etc,
-  cimp dissesse dissesses dissesse dissssemos dissessem
+  cimp dissesse dissesses dissesse dissêssemos dissessem
   cond diria etc,
   ivo diz,
   pp dito
@@ -1530,29 +1557,29 @@ dizer = antedizer bendizer condizer contradizer desdizer
         interdizer maldizer predizer
 fazer = contrafazer desfazer satisfazer refazer
 fazer:
-  fao . faz ,
+  faço . faz ,
   fiz fizeste fez fizemos fizeram ,
-  fazia fazias fazia fazamos faziam,
-  fut farei fars far faremos faro,
-  fizera etc , # fizeras fizera fizramos fizeram,
-  faa etc , # faas faa faamos faam,
-  cond faria etc , # farias faria faramaos faria
+  fazia fazias fazia fazíamos faziam,
+  fut farei farás fará faremos farão,
+  fizera etc , # fizeras fizera fizéramos fizeram,
+  faça etc , # faças faça façamos façam,
+  cond faria etc , # farias faria faríamaos faria
   ivo faz 
   pp feito
 dar: 
-  dou ds d damos dais do,
+  dou dás dá damos dais dão,
   dei deste etc 
-  mdp dera deras dera dramos deram,
-  d ds d dmos deis dem,
+  mdp dera deras dera déramos deram,
+  dê dês dê dêmos deis dêem,
   desse etc 
   der deres der dermos derem ,
-  ivo d . demos
+  ivo dá . demos
 poder:
   posso podes etc
-  pude pudeste pde pudemos puderam, 
+  pude pudeste pôde pudemos puderam, 
   mdp pudera etc
   cpres possa etc
-  cimp pudesse pudesses pudesse pudssemos pudessem 
+  cimp pudesse pudesses pudesse pudéssemos pudessem 
 # DLPO defines ivo like here, GPVP says it isn't defined
   ivo pode
 caber:
@@ -1568,12 +1595,12 @@ sentir:
   ivo sente sinta sintamos senti sintam
 sentir = ressentir assentir consentir mentir desmentir investir revestir desinvestir vestir
 ir:
-  vou  vais  vai vamos ides vo ,
+  vou  vais  vai vamos ides vão ,
   fui  foste foi fomos fostes foram , 
-  cpres v vs v vamos vades vo, 
-  fosse fosses fosse fssemos fsseis fossem,
+  cpres vá vás vá vamos vades vão, 
+  fosse fosses fosse fôssemos fôsseis fossem,
   for fores for formos fordes foram
-  ivo vai v vamos ide vo
+  ivo vai vá vamos ide vão
 valer:
   valho vales vale valemos valem,
   cpres valha etc
@@ -1581,14 +1608,14 @@ valer:
 prover: perf provi etc pp provido model ver 
 rever:  model ver 
 sair:
-  saio sais sai samos sas saem,
-  sa saste saiu samos sastes saram,
-  saa saas saa saamos saeis saam
-  mdp sara saras sara saramos sareis saram
+  saio sais sai saímos saís saem,
+  saí saíste saiu saímos saístes saíram,
+  saía saías saía saíamos saíeis saíam
+  mdp saíra saíras saíra saíramos saíreis saíram
   cpres saia saias saia saiamos saiais saiam
-  cimp sasse sasses sasse sassemos sasseis sassem
-  cfut sair sares sair sairmos sairdes sarem
-  ivo   sai saia saiamos sa saiam
+  cimp saísse saísses saísse saíssemos saísseis saíssem
+  cfut sair saíres sair sairmos sairdes saírem
+  ivo   sai saia saiamos saí saiam
 abrir: pp aberto
 abrir = entreabrir
 saber:  
@@ -1620,7 +1647,7 @@ trazer:
   trago trazes traz trazemos trazem,
   trouxe trouxeste trouxe etc
   mdp trouxera acc etc 
-  fut trarei trars trar traremos traro, 
+  fut trarei trarás trará traremos trarão, 
   cpres traga etc
   cond traria etc
   ivo traz traga etc
@@ -1632,53 +1659,54 @@ seguir:
 seguir = perseguir prosseguir conseguir
 #  pres perf imp fut mdp  cpres cimp cfut cond ivo pp grd 
 ler:
-  leio ls l lemos lem
+  leio lês lê lemos lêem
   cpres  leia leias leia leiamos  leiam
-  ivo   l lia leiamos leiam
+  ivo   lê lêia leiamos leiam
 ler = reler tresler
 atribuir:
-  atribuo atribuis atribui atribumos atribus atribuem,
-  atribu atribuste  atribuiu  atribumos  atriburam, 
-  atribua atribuas  atribua  atribuamos  atribuam, 
+  atribuo atribuis atribui atribuímos atribuís atribuem,
+  atribuí atribuíste  atribuiu  atribuímos  atribuíram, 
+  atribuía atribuías  atribuía  atribuíamos  atribuíam, 
   cfut   atribuir . atribuir atribuirmos .
   ivo atribui
-	pp atribudo
+	pp atribuído
 averiguar: 
-  cpres averige averiges  averige .  averigem 
+  cpres averigúe averigúes  averigúe .  averigúem 
   ivo averigua
 pedir: 
-  peo cpres pea etc ivo pede pea peamos    pedi peam
+  peço cpres peça etc ivo pede peça peçamos    pedi peçam
 ver:  
-  vejo vs  v vemos vem,
+  vejo vês  vê vemos vêem,
   vi    viste viu vimos viram,
   mdp vira etc
   cpres veja vejas veja vejamos vejam
-  cimp visse visses visse vssemos vsseis vissem
-  ivo v veja  vejamos vede vejam
+  cimp visse visses visse víssemos vísseis vissem
+  ivo vê veja  vejamos vede vejam
   pp visto
 ver = antever entrever prever rever 
 vir:  
-  venho vens vem vimos vindes vm,
+  venho vens vem vimos vindes vêm,
   vim vieste veio viemos viestes vieram,
-  vinha vinhas vinha vnhamos vnheis vinham,
-  mdp   viera vieras viera viramos vieram,
+  vinha vinhas vinha vínhamos vínheis vinham,
+  mdp   viera vieras viera viéramos vieram,
   cpres venha venhas venha venhamos venham,
-  cimp viesse viesses viesse vissemos visseis viessem,
+  cimp viesse viesses viesse viéssemos viésseis viessem,
   cfut vier vieres vier viermos vierdes vierem,
   ivo vem venha vinhamos vinde venham
   pp vindo
 vir = advir convir intervir   
 
 ouvir: 
-  o(i|u)o ouves ouve ouvimos ouvem, 
-  cpres o(i|u)a etc # ouas oua ouamos ouam,
-  # alternative : cpres oia  oias  oia  oiamos  oiam 
-  ivo ouve oia 
-  # alternative : ivo . oia 
+  o(i|u)ço ouves ouve ouvimos ouvem, 
+  cpres o(i|u)ça etc # ouças ouça ouçamos ouçam,
+  # alternative : cpres oiça  oiças  oiça  oiçamos  oiçam 
+  ivo ouve oiça 
+  # alternative : ivo . oiça 
 rir:
   rio ris ri rimos rides riem
-  cpres ria rias ria ramos reis riam
+  cpres ria rias ria riamos riais riam
   ivo ri ria riamos ride riam 
+rir = sorrir
 fugir: 
   fujo foges foge fugimos fogem ivo foge
 dormir:   durmo , cpres durma 
@@ -1692,13 +1720,13 @@ escrever: pp escrito
 escrever = descrever inscrever reescrever prescrever
 dormir =  abolir demolir engolir
 
-influir: . . . . influs .
-          ivo . . . influ .
-          cimp influsse influsses influsse . . influssem
+influir: . . . . influís .
+          ivo . . . influí .
+          cimp influísse influísses influísse . . influíssem
 
-construir: . constr(|u)is constr(|u)i . . constr(o|u)em
+construir: . constr(ó|u)is constr(ó|u)i . . constr(o|u)em
          model influir
-destruir: . destr(|u)is destr(|u)i . . destr(o|u)em
+destruir: . destr(ó|u)is destr(ó|u)i . . destr(o|u)em
          model influir
 polir:
     pulo pules pule polimos polis pulem
@@ -1714,13 +1742,13 @@ subir:
 reaver:
        x x x  reavemos reaveis x ,
        reouve reouveste reouve reouvemos reouvestes reouveram,
-       reavia reavias reavia reavamos reaveis reaviam,
-       reaverei reavers reaver reaveremos reavereis reavero,
-       reouvera reouveras reouvera reouvramos reouvreis reouveram,
+       reavia reavias reavia reavíamos reavíeis reaviam,
+       reaverei reaverás reaverá reaveremos reavereis reaverão,
+       reouvera reouveras reouvera reouvéramos reouvéreis reouveram,
        x x x x x x,
-       reouvesse reouvesses reouvesse reouvssemos reouvsseis reouvessem,
+       reouvesse reouvesses reouvesse reouvéssemos reouvésseis reouvessem,
        reouver reouveres reouver reouvermos reouverdes reouverem,
-       reaveria reaverias reaveria reaveramos reavereis reaveriam,
+       reaveria reaverias reaveria reaveríamos reaveríeis reaveriam,
        x x x x x, reavido  reavendo
 pedir = despedir medir impedir expedir
 perder:
@@ -1728,17 +1756,17 @@ perder:
   cpres perca percas perca percais percam
   ivo perde perca percamos
 crer:
-  creio crs cr . credes crem,
+  creio crês crê . credes crêem,
   cpres creia creias creia creiamos creiais creiam
-  ivo  cr . . crede
-# Double Particpio Passado
+  ivo  crê . . crede
+# Double Particípio Passado
 aceitar: pp aceit(o|e|ado)
-afeioar: pp afe(ct|ioad)o
+afeiçoar: pp afe(ct|içoad)o
 cativar: pp cativ(|ad)o
 cegar: pp ceg(|ad)o
 completar: pp complet(|ad)o
 cultivar: pp cult(|ivad)o
-descalar: pp descal(|ad)o
+descalçar: pp descalç(|ad)o
 entregar: pp entreg(ue|ado)
 enxugar: pp enxu(t|gad)o
 expulsar: pp expuls(|ad)o
@@ -1759,7 +1787,7 @@ secar: pp sec(|ad)o
 segurar: pp segur(|ad)o
 fechar: pp fech(|ad)o
 afligir: pp afli(t|gid)o 
-concluir:pp conclu(s|d)o
+concluir:pp conclu(s|íd)o
 corrigir:pp corr(ect|igid)o
 dirigir:pp dir(ect|igid)o
 distingir:pp distin(t|guid)o
@@ -1770,7 +1798,7 @@ extinguir:pp ext(int|inguid)o
 frigir:pp fri(t|gid)o
 imergir:pp imer(s|gid)o
 imprimir:pp impr(ess|imid)o
-incluir:pp inclu(s|d)o
+incluir:pp inclu(s|íd)o
 inserir:pp ins(ert|erid)o
 omitir:pp om(ess|itid)o
 oprimir:pp opr(ess|imid)o
